==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/AutoTargetLagsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.AutoTargetLagsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property mode Target lags selection modes.
 * Expected value is 'Auto'.
 */
public data class AutoTargetLagsArgs(
    public val mode: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.AutoTargetLagsArgs> {
    override fun toJava(): com.pulumi.azurenative.machinelearningservices.inputs.AutoTargetLagsArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.AutoTargetLagsArgs.builder()
            .mode(mode.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AutoTargetLagsArgs].
 */
@PulumiTagMarker
public class AutoTargetLagsArgsBuilder internal constructor() {
    private var mode: Output<String>? = null

    /**
     * @param value Target lags selection modes.
     * Expected value is 'Auto'.
     */
    @JvmName("dqpebwqutjcdjchc")
    public suspend fun mode(`value`: Output<String>) {
        this.mode = value
    }

    /**
     * @param value Target lags selection modes.
     * Expected value is 'Auto'.
     */
    @JvmName("pvyinayibxowlqxx")
    public suspend fun mode(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    internal fun build(): AutoTargetLagsArgs = AutoTargetLagsArgs(
        mode = mode ?: throw PulumiNullFieldException("mode"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/AutoTargetLagsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.AutoTargetLagsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property mode Target lags selection modes.
 * Expected value is 'Auto'.
 */
public data class AutoTargetLagsArgs(
    public val mode: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.AutoTargetLagsArgs> {
    override fun toJava(): com.pulumi.azurenative.machinelearningservices.inputs.AutoTargetLagsArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.AutoTargetLagsArgs.builder()
            .mode(mode.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AutoTargetLagsArgs].
 */
@PulumiTagMarker
public class AutoTargetLagsArgsBuilder internal constructor() {
    private var mode: Output<String>? = null

    /**
     * @param value Target lags selection modes.
     * Expected value is 'Auto'.
     */
    @JvmName("nkudaiuvoyhhinyb")
    public suspend fun mode(`value`: Output<String>) {
        this.mode = value
    }

    /**
     * @param value Target lags selection modes.
     * Expected value is 'Auto'.
     */
    @JvmName("vhineiigffdvkwrl")
    public suspend fun mode(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    internal fun build(): AutoTargetLagsArgs = AutoTargetLagsArgs(
        mode = mode ?: throw PulumiNullFieldException("mode"),
    )
}
